@@ -17,7 +17,7 @@ static int AddContextCases() {
   AddCases(TC_ConsoleErr,
            {
                {"^%int-%int-%intT%int:%int:%int[-+]%int:%int$", MR_Default},
-               {"Running .*/reporter_output_test(\\.exe)?$", MR_Next},
+               {"Running .*(/|\\\\)reporter_output_test(\\.exe)?$", MR_Next},
                {"Run on \\(%int X %float MHz CPU s?\\)", MR_Next},
            });
   AddCases(TC_JSONOut,
@@ -943,7 +943,7 @@ ADD_CASES(
 // ------------- Testing relative standard deviation statistics ------------ //
 // ========================================================================= //
 
-const auto UserPercentStatistics = [](const std::vector<double>& v) {
+const auto UserPercentStatistics = [](const std::vector<double>&) {
   return 1. / 100.;
 };
 void BM_UserPercentStats(benchmark::State& state) {
